"""这是本人写的第二个Python模块"""
def print_hh(the_list, level=0):
    for each in the_list:
        if isinstance(each, list):
            print_hh(each, level+1)
        else:
            for i in range(level):
                print('\t', end='')
            print(each)


from distutils.core import setup

setup(
    name         = 'zhou',
    version      = '1.0.0',
    py_modules   = ['cz_use'],
    author       = 'changzhi_zhou',
    url          = 'http://baidu.com',
    description  = 'A simple printer of hhh'
)